==> peperit_2.0_estable.zip: themes/peperit/html_files/privacidad.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Politica de privacidad
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
// Incluimos la miga
//escupirMiga("Política de privacidad");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Política de privacidad', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">
            <?php
            //---------------------------------------------------------------------------------------------------------
            // 16/Mayo/2019- (Marina)
            // Version actualizada de la Politica de Privacidad, utilizando variables para obtener los datos
            //---------------------------------------------------------------------------------------------------------
            ?>
                <h3><?= traducir('1 IDENTIFICACIÓN'); ?></h3> 

                <p><?= traducir('Titular: %-Shop::$empresa->nombre_legal-%')?></p>
                <p><?= traducir('Domicilio social: %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-% %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%).')?> </p>
                <p><?= traducir('N.I.F.: %-Shop::$empresa->cif-%');?></p>
                <p><?= traducir('E-mail: %-Shop::$empresa->email_empresa-%');?></p>

                <h3><?= traducir('2 INFORMACIÓN Y CONSENTIMIENTO'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el Reglamento UE 679/2015 de Protección de Datos, mediante la aceptación de la presente Política de Privacidad el Usuario (en adelante, el “Usuario”) presta su consentimiento informado, expreso, libre e inequívoco para que los datos personales recabados a través del Sitio Web %-Shop::$configuracion->url-% (en adelante, el “Sitio Web”) sean tratados por %-Shop::$empresa->nombre_legal-% conforme a lo dispuesto en la presente Política de Privacidad'); ?></p>

                <p><?= traducir('Todos los datos personales solicitados al Usuario en el Sitio Web son obligatorios, no siendo posible el acceso o registro en Sitio Web si no se facilitan dichos datos.');?></p>

                <p><?= traducir('Asimismo, cuando los datos personales sean recabados a través de formularios que se puedan habilitar en el Sitio Web con motivo del desarrollo de su actividad, será necesario que el Usuario aporte, al menos, aquellos marcados con un asterisco ya que, si no se suministrasen esos datos considerados necesarios, no podremos prestar el servicio al Usuario a través del Sitio Web.'); ?></p>

                <p><?= traducir('El Usuario garantiza que los datos personales facilitados a %-Shop::$empresa->nombre_legal-% son ciertos y exactos, con lo que %-Shop::$empresa->nombre_legal-% no se hará responsable de cualquier incidencia derivada de la inexactitud o falsedad de la información proporcionada por los Usuarios.'); ?></p>

                <p><?= traducir('El Usuario, como único responsable del tratamiento, será responsable de cumplir con toda la normativa de protección de datos aplicable. Además, el Usuario acepta obtener todos los consentimientos, autorizaciones y/o aprobaciones legalmente necesarias antes de incluir datos personales en el Sitio Web o utilizar el Sitio Web.'); ?></p>

                <h3><?= traducir('3 FINALIDAD DEL TRATAMIENTO'); ?></h3>

                <p><?= traducir('Los datos personales del Usuario o de terceros que sean cedidos por el Usuario serán tratados por %-Shop::$empresa->nombre_legal-% a través de Sitio Web únicamente para las siguientes finalidades:'); ?></p>
                <ul>
                    <li><?= traducir('• Llevar a cabo las funcionalidades del Sitio Web destinadas a la prestación de los servicios ofrecidos en el mismo.'); ?></li>
                    <li><?= traducir('• Dar cumplimiento a las obligaciones legalmente establecidas.'); ?></li>
                </ul>

                <p><?= traducir('En ningún caso realizaremos alguna de las siguientes actividades:'); ?></p>
                <ul>
                    <li><?= traducir('• Ceder los datos a otras personas o entidades, sin el consentimiento previo de los Usuarios.'); ?></li>
                    <li><?= traducir('• Transferirlos a otros Estados, sin el consentimiento previo de los Usuarios.'); ?></li>
                </ul>

                <h3><?= traducir('4 DATOS DEL USUARIO'); ?></h3>

                <p><?= traducir('El Usuario garantiza que los datos aportados son verdaderos, exactos, completos y actualizados, siendo éste responsable de cualquier daño o perjuicio, directo o indirecto, que pudiera ocasionarse como consecuencia del incumplimiento de tal obligación.')?></p>

                <p><?= traducir('En el caso de que los datos aportados pertenecieran a un tercero, el Usuario garantiza que ha informado a dicho tercero de los aspectos contenidos en este documento y obtenido su autorización para facilitar sus datos al responsable para los fines anteriormente señalados.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% no puede garantizar la absoluta invulnerabilidad de los sistemas, por tanto, no asume ninguna responsabilidad por los daños y perjuicios derivados de alteraciones que terceros puedan causar en los sistemas informáticos, documentos electrónicos o ficheros.')?></p>

                <h3><?= traducir('5 ESTAMPACIÓN DE ARCHIVOS A BLOCKCHAIN A TRAVÉS DEL SITIO WEB'); ?></h3>

                <p><?= traducir('El Sitio Web ofrece una solución a los Usuarios para estampar archivos en la “cadena de bloques”/blockchain de Ethereum, Bitcoin y Litecoin mediante el cifrado y sistema de hash de los mismos. Este servicio no tendrá, en ningún caso, la consideración de comunicaciones de datos a dichas blockchain, debido a la imposibilidad de descifrar los mismos y adquiriendo, de dicho modo, la consideración de datos anonimizados.'); ?></p>

                <p><?= traducir('Dichos archivos, no obstante, serán conservados de forma pseudonimizada por %-Shop::$empresa->nombre_legal-% durante un periodo de un año con la única finalidad de permitir al Usuario recibir dicho archivo para comprobar que sigue inalterado en las referidas blockchain.'); ?></p>

                <h3><?= traducir('6 POLÍTICA DE COOKIES'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el RGPD y la Ley 34/2002, de Servicios de la Sociedad de la Información, todos los datos de carácter personal obtenidos mediante las cookies durante la utilización de Sitio Web, serán tratados de conformidad con lo dispuesto en la Política de Cookies.')?></p>

                <h3><?= traducir('7 EJERCICIO DE DERECHOS'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el RGPD, le informamos que puede ejercer sus derechos de acceso, rectificación, cancelación, oposición, limitación del tratamiento y portabilidad, solicitándolo por escrito a través de cualquiera de los medios siguientes, adjuntando en todo caso una copia de documento acreditativo de su identidad y concretando el derecho o derechos que desea ejercer, directamente a %-Shop::$empresa->nombre_legal-% a través del siguiente e-mail: %-Shop::$empresa->email_empresa-%');?></p>

                <p><?= traducir('En caso de cualquier duda, o en el supuesto de que no considere que ha sido debidamente atendido, por favor, no dude en contactar y transmitir su queja al Responsable de Protección de Datos de nuestra entidad en el correo %-Shop::$empresa->email_empresa-% o mediante carta postal dirigida a la misma dirección.'); ?></p>

                <div class="volver">
                </div> 
            </article>
        </div>
    </div>
</section>

==> peperit_2.1_estable.zip: themes/peperit/html_files/privacidad.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Politica de privacidad
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
// Incluimos la miga
//escupirMiga("Política de privacidad");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Política de privacidad', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">
            <?php
            //---------------------------------------------------------------------------------------------------------
            // 16/Mayo/2019- (Marina)
            // Version actualizada de la Politica de Privacidad, utilizando variables para obtener los datos
            //---------------------------------------------------------------------------------------------------------
            ?>
                <h3><?= traducir('1 IDENTIFICACIÓN'); ?></h3> 

                <p><?= traducir('Titular: %-Shop::$empresa->nombre_legal-% en adelante %-Shop::$empresa->nombre-%')?> </p>
                <p><?= traducir('Domicilio social: %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-% %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%).')?> </p>
                <p><?= traducir('N.I.F.: %-Shop::$empresa->cif-%');?></p>
                <p><?= traducir('E-mail: %-Shop::$empresa->email_empresa-%');?></p>

                <h3><?= traducir('2 INFORMACIÓN Y CONSENTIMIENTO'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el Reglamento UE 679/2015 de Protección de Datos, mediante la aceptación de la presente Política de Privacidad el Usuario (en adelante, el “Usuario”) presta su consentimiento informado, expreso, libre e inequívoco para que los datos personales recabados a través del Sitio Web %-Shop::$configuracion->url-% (en adelante, el “Sitio Web”) sean tratados por %-Shop::$empresa->nombre-% conforme a lo dispuesto en la presente Política de Privacidad'); ?></p>

                <p><?= traducir('Todos los datos personales solicitados al Usuario en el Sitio Web son obligatorios, no siendo posible el acceso o registro en Sitio Web si no se facilitan dichos datos.');?></p>

                <p><?= traducir('Asimismo, cuando los datos personales sean recabados a través de formularios que se puedan habilitar en el Sitio Web con motivo del desarrollo de su actividad, será necesario que el Usuario aporte, al menos, aquellos marcados con un asterisco ya que, si no se suministrasen esos datos considerados necesarios, no podremos prestar el servicio al Usuario a través del Sitio Web.'); ?></p>

                <p><?= traducir('El Usuario garantiza que los datos personales facilitados a %-Shop::$empresa->nombre-% son ciertos y exactos, con lo que %-Shop::$empresa->nombre-% no se hará responsable de cualquier incidencia derivada de la inexactitud o falsedad de la información proporcionada por los Usuarios.'); ?></p>

                <p><?= traducir('El Usuario, como único responsable del tratamiento, será responsable de cumplir con toda la normativa de protección de datos aplicable. Además, el Usuario acepta obtener todos los consentimientos, autorizaciones y/o aprobaciones legalmente necesarias antes de incluir datos personales en el Sitio Web o utilizar el Sitio Web.'); ?></p>

                <h3><?= traducir('3 FINALIDAD DEL TRATAMIENTO'); ?></h3>

                <p><?= traducir('Los datos personales del Usuario o de terceros que sean cedidos por el Usuario serán tratados por %-Shop::$empresa->nombre-% a través de Sitio Web únicamente para las siguientes finalidades:'); ?></p>
                <ul>
                    <li><?= traducir('• Llevar a cabo las funcionalidades del Sitio Web destinadas a la prestación de los servicios ofrecidos en el mismo.'); ?></li>
                    <li><?= traducir('• Dar cumplimiento a las obligaciones legalmente establecidas.'); ?></li>
                </ul>

                <p><?= traducir('En ningún caso realizaremos alguna de las siguientes actividades:'); ?></p>
                <ul>
                    <li><?= traducir('• Ceder los datos a otras personas o entidades, sin el consentimiento previo de los Usuarios.'); ?></li>
                    <li><?= traducir('• Transferirlos a otros Estados, sin el consentimiento previo de los Usuarios.'); ?></li>
                </ul>

                <h3><?= traducir('4 DATOS DEL USUARIO'); ?></h3>

                <p><?= traducir('El Usuario garantiza que los datos aportados son verdaderos, exactos, completos y actualizados, siendo éste responsable de cualquier daño o perjuicio, directo o indirecto, que pudiera ocasionarse como consecuencia del incumplimiento de tal obligación.')?></p>

                <p><?= traducir('En el caso de que los datos aportados pertenecieran a un tercero, el Usuario garantiza que ha informado a dicho tercero de los aspectos contenidos en este documento y obtenido su autorización para facilitar sus datos al responsable para los fines anteriormente señalados.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre-% no puede garantizar la absoluta invulnerabilidad de los sistemas, por tanto, no asume ninguna responsabilidad por los daños y perjuicios derivados de alteraciones que terceros puedan causar en los sistemas informáticos, documentos electrónicos o ficheros.')?></p>

                <h3><?= traducir('5 ESTAMPACIÓN DE ARCHIVOS A BLOCKCHAIN A TRAVÉS DEL SITIO WEB'); ?></h3>

                <p><?= traducir('El Sitio Web ofrece una solución a los Usuarios para estampar archivos en la “cadena de bloques”/blockchain de Ethereum, Bitcoin y Litecoin mediante el cifrado y sistema de hash de los mismos. Este servicio no tendrá, en ningún caso, la consideración de comunicaciones de datos a dichas blockchain, debido a la imposibilidad de descifrar los mismos y adquiriendo, de dicho modo, la consideración de datos anonimizados.'); ?></p>

                <p><?= traducir('Dichos archivos, no obstante, serán conservados de forma pseudonimizada por %-Shop::$empresa->nombre-% durante un periodo de un año con la única finalidad de permitir al Usuario recibir dicho archivo para comprobar que sigue inalterado en las referidas blockchain.'); ?></p>

                <h3><?= traducir('6 POLÍTICA DE COOKIES'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el RGPD y la Ley 34/2002, de Servicios de la Sociedad de la Información, todos los datos de carácter personal obtenidos mediante las cookies durante la utilización de Sitio Web, serán tratados de conformidad con lo dispuesto en la Política de Cookies.')?></p>

                <h3><?= traducir('7 EJERCICIO DE DERECHOS'); ?></h3>

                <p><?= traducir('De conformidad con lo dispuesto en el RGPD, le informamos que puede ejercer sus derechos de acceso, rectificación, cancelación, oposición, limitación del tratamiento y portabilidad, solicitándolo por escrito a través de cualquiera de los medios siguientes, adjuntando en todo caso una copia de documento acreditativo de su identidad y concretando el derecho o derechos que desea ejercer, directamente a %-Shop::$empresa->nombre-% a través del siguiente e-mail: %-Shop::$empresa->email_empresa-%');?></p>

                <p><?= traducir('En caso de cualquier duda, o en el supuesto de que no considere que ha sido debidamente atendido, por favor, no dude en contactar y transmitir su queja al Responsable de Protección de Datos de nuestra entidad en el correo %-Shop::$empresa->email_empresa-% o mediante carta postal dirigida a la misma dirección.'); ?></p>

                <div class="volver">
                </div> 
            </article>
        </div>
    </div>
</section>
